=== added directory 'lib/lp/services/librarianserver/doc'
=== renamed file 'lib/lp/services/librarianserver/tests/librarian-report.txt' => 'lib/lp/services/librarianserver/doc/librarian-report.txt'
=== renamed file 'lib/lp/services/librarianserver/tests/test_upload.txt' => 'lib/lp/services/librarianserver/doc/upload.txt'
=== removed directory 'lib/lp/services/librarianserver/ftests'
=== removed file 'lib/lp/services/librarianserver/ftests/__init__.py'
=== renamed file 'lib/lp/services/librarianserver/ftests/test_db.py' => 'lib/lp/services/librarianserver/tests/test_db.py'
=== modified file 'lib/lp/services/librarianserver/tests/test_doc.py'
--- lib/lp/services/librarianserver/tests/test_doc.py	2011-12-28 17:03:06 +0000
+++ lib/lp/services/librarianserver/tests/test_doc.py	2011-12-30 02:19:42 +0000
@@ -5,10 +5,14 @@
 Run the doctests and pagetests.
 """
 
+__metaclass__ = type
+
 import os
 
 from lp.testing.layers import LaunchpadZopelessLayer
 from lp.services.testing import build_test_suite
+from lp.services.librarianserver.libraryprotocol import FileUploadProtocol
+from lp.services.librarianserver.storage import WrongDatabaseError
 from lp.testing.systemdocs import (
     LayeredDocFileSuite,
     setUp,
@@ -16,14 +20,126 @@
     )
 
 
+class MockTransport:
+    disconnecting = False
+
+    bytesWritten = ''
+    connectionLost = False
+
+    def write(self, bytes):
+        self.bytesWritten += bytes
+
+    def loseConnection(self):
+        self.connectionLost = True
+        self.disconnecting = True
+
+
+class MockLibrary:
+    file = None
+    def startAddFile(self, name, size):
+        self.file = MockFile(name)
+        return self.file
+
+
+class MockFile:
+    bytes = ''
+    stored = False
+    databaseName = None
+    debugID = None
+    debugLog = ()
+
+    def __init__(self, name):
+        self.name = name
+
+    def append(self, bytes):
+        self.bytes += bytes
+
+    def store(self):
+        databaseName = self.databaseName
+        if databaseName is not None and databaseName != 'right_database':
+            raise WrongDatabaseError(databaseName, 'right_database')
+        self.stored = True
+        return (987, 654)
+
+
+def upload_request(request):
+    """Librarian upload server test helper, process a request and report what
+    happens.
+
+    Hands a request to a librarian file upload protocol, and prints the reply
+    from the server, a summary of the file uploaded, and whether the connection
+    closed, e.g.::
+
+        reply: '200'
+        file u'foo.txt' stored as text/plain, contents: 'Foo!'
+
+    or::
+
+        reply: '400 STORE command expects the filename to be in UTF-8'
+        connection closed
+
+    Note that the Librarian itself except for the protocol logic is stubbed out
+    by this function; it's intended to be used to unit test the protocol
+    implementation, not end-to-end test the Librarian.
+    """
+    # Send tracebacks from Twisted to stderr, if they occur, to make debugging
+    # test failures easier.
+    import sys
+    def log_observer(x):
+        print >> sys.stderr, x
+        if 'failure' in x:
+            x['failure'].printTraceback(file=sys.stderr)
+    from twisted.python import log
+    log.addObserver(log_observer)
+
+    # Create a FileUploadProtocol, and instrument it for testing:
+    server = FileUploadProtocol()
+
+    #  * hook _storeFile to dispatch straight to newFile.store without
+    #    spawning a thread.
+    from twisted.internet import defer
+    server._storeFile = lambda: defer.maybeDeferred(server.newFile.store)
+
+    #  * give it a fake transport
+    server.transport = MockTransport()
+    server.connectionMade()
+
+    #  * give it a fake factory (itself!), and a fake library.
+    server.factory = server
+    server.fileLibrary = MockLibrary()
+
+    # Feed in the request
+    server.dataReceived(request.replace('\n', '\r\n'))
+
+    # Report on what happened
+    print "reply: %r" % server.transport.bytesWritten.rstrip('\r\n')
+
+    if server.transport.connectionLost:
+        print 'connection closed'
+
+    mockFile = server.fileLibrary.file
+    if mockFile is not None and mockFile.stored:
+        print "file %r stored as %s, contents: %r" % (
+                mockFile.name, mockFile.mimetype, mockFile.bytes)
+
+    # Cleanup: remove the observer.
+    log.removeObserver(log_observer)
+
+
 here = os.path.dirname(os.path.realpath(__file__))
 
 special = {
     'librarian-report.txt': LayeredDocFileSuite(
-            'librarian-report.txt',
+            '../doc/librarian-report.txt',
             setUp=setUp, tearDown=tearDown,
             layer=LaunchpadZopelessLayer
             ),
+    'upload.txt': LayeredDocFileSuite(
+            '../doc/upload.txt',
+            setUp=setUp, tearDown=tearDown,
+            layer=LaunchpadZopelessLayer,
+            globs={'upload_request': upload_request},
+            ),
 }
 
 def test_suite():

=== renamed file 'lib/lp/services/librarianserver/ftests/test_gc.py' => 'lib/lp/services/librarianserver/tests/test_gc.py'
=== renamed file 'lib/lp/services/librarianserver/ftests/test_storage.py' => 'lib/lp/services/librarianserver/tests/test_storage_db.py'
=== removed file 'lib/lp/services/librarianserver/tests/test_upload.py'
--- lib/lp/services/librarianserver/tests/test_upload.py	2011-12-30 01:48:17 +0000
+++ lib/lp/services/librarianserver/tests/test_upload.py	1970-01-01 00:00:00 +0000
@@ -1,121 +0,0 @@
-# Copyright 2009 Canonical Ltd.  This software is licensed under the
-# GNU Affero General Public License version 3 (see the file LICENSE).
-
-__metaclass__ = type
-
-from lp.services.librarianserver.libraryprotocol import FileUploadProtocol
-from lp.services.librarianserver.storage import WrongDatabaseError
-from lp.testing.systemdocs import LayeredDocFileSuite
-
-
-class MockTransport:
-    disconnecting = False
-
-    bytesWritten = ''
-    connectionLost = False
-
-    def write(self, bytes):
-        self.bytesWritten += bytes
-
-    def loseConnection(self):
-        self.connectionLost = True
-        self.disconnecting = True
-
-
-class MockLibrary:
-    file = None
-    def startAddFile(self, name, size):
-        self.file = MockFile(name)
-        return self.file
-
-
-class MockFile:
-    bytes = ''
-    stored = False
-    databaseName = None
-    debugID = None
-    debugLog = ()
-
-    def __init__(self, name):
-        self.name = name
-
-    def append(self, bytes):
-        self.bytes += bytes
-
-    def store(self):
-        databaseName = self.databaseName
-        if databaseName is not None and databaseName != 'right_database':
-            raise WrongDatabaseError(databaseName, 'right_database')
-        self.stored = True
-        return (987, 654)
-
-
-def upload_request(request):
-    """Librarian upload server test helper, process a request and report what
-    happens.
-
-    Hands a request to a librarian file upload protocol, and prints the reply
-    from the server, a summary of the file uploaded, and whether the connection
-    closed, e.g.::
-
-        reply: '200'
-        file u'foo.txt' stored as text/plain, contents: 'Foo!'
-
-    or::
-
-        reply: '400 STORE command expects the filename to be in UTF-8'
-        connection closed
-
-    Note that the Librarian itself except for the protocol logic is stubbed out
-    by this function; it's intended to be used to unit test the protocol
-    implementation, not end-to-end test the Librarian.
-    """
-    # Send tracebacks from Twisted to stderr, if they occur, to make debugging
-    # test failures easier.
-    import sys
-    def log_observer(x):
-        print >> sys.stderr, x
-        if 'failure' in x:
-            x['failure'].printTraceback(file=sys.stderr)
-    from twisted.python import log
-    log.addObserver(log_observer)
-
-    # Create a FileUploadProtocol, and instrument it for testing:
-    server = FileUploadProtocol()
-
-    #  * hook _storeFile to dispatch straight to newFile.store without
-    #    spawning a thread.
-    from twisted.internet import defer
-    server._storeFile = lambda: defer.maybeDeferred(server.newFile.store)
-
-    #  * give it a fake transport
-    server.transport = MockTransport()
-    server.connectionMade()
-
-    #  * give it a fake factory (itself!), and a fake library.
-    server.factory = server
-    server.fileLibrary = MockLibrary()
-
-    # Feed in the request
-    server.dataReceived(request.replace('\n', '\r\n'))
-
-    # Report on what happened
-    print "reply: %r" % server.transport.bytesWritten.rstrip('\r\n')
-
-    if server.transport.connectionLost:
-        print 'connection closed'
-
-    mockFile = server.fileLibrary.file
-    if mockFile is not None and mockFile.stored:
-        print "file %r stored as %s, contents: %r" % (
-                mockFile.name, mockFile.mimetype, mockFile.bytes)
-
-    # Cleanup: remove the observer.
-    log.removeObserver(log_observer)
-
-
-def test_suite():
-    return LayeredDocFileSuite(
-        'test_upload.txt', globs={'upload_request': upload_request},
-        stdout_logging=False)
-

=== renamed file 'lib/lp/services/librarianserver/ftests/test_web.py' => 'lib/lp/services/librarianserver/tests/test_web.py'
=== modified file 'utilities/smoke-test-librarian.py'
--- utilities/smoke-test-librarian.py	2011-12-30 01:48:17 +0000
+++ utilities/smoke-test-librarian.py	2011-12-30 02:19:42 +0000
@@ -6,10 +6,10 @@
 """Perform simple librarian operations to verify the current configuration.
 """
 
+import _pythonpath # Not lint, actually needed.
+
 import sys
 
-import _pythonpath # Not lint
-import actually needed.
 from zope.component import getUtility
 
 from lp.services.librarian.interfaces.client import (

